package com.muyu.openbusiness.controller;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.muyu.common.system.domain.SysUser;
import com.muyu.common.system.remote.RemoteDataService;
import com.muyu.common.system.remote.RemoteUserService;
import com.muyu.openbusiness.apply.VehiCachService;
import com.muyu.openbusiness.domain.SysCar;
import com.muyu.openbusiness.domain.SysCarMessage;

import com.muyu.openbusiness.domain.req.SysCarMessageReq;
import com.muyu.openbusiness.service.ISysCarMessageService;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.security.annotation.RequiresPermissions;
import jakarta.servlet.http.HttpServletResponse;
import jakarta.servlet.http.HttpSession;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.concurrent.CompletableFuture;
import java.util.concurrent.ExecutionException;

/**
 * 车辆报文记录Controller
 *
 * @author muyu
 * @date 2024-09-18
 */
@RestController

@RequestMapping("/messageInfo")
public class SysCarMessageController extends BaseController {
    @Resource
    private ISysCarMessageService sysCarMessageService;
    @Resource
    private RemoteDataService remoteDataService;


    /**
     * 查询车辆报文记录列表
     */
    @RequiresPermissions("message:message:list")
    @GetMapping("/list")
    public Result<List<SysCarMessage>> list(SysCarMessageReq sysCarMessage) {
        remoteDataService.carRealTimeStatus(sysCarMessage.getCarVin(),sysCarMessage.getFlag());
        SysCarMessage message = new SysCarMessage();
        message.setModelCode(sysCarMessage.getModelCode());
        List<SysCarMessage> list = sysCarMessageService.selectSysCarMessageList(message);

        /*list.forEach(syscar -> {
            List<SysCar> list1 = sysCarMessageService.selectSysCarMessageList(new LambdaQueryWrapper<SysCar>()
                    .eq(SysCar::getCarType, syscar.getMessageType()));
            list1.forEach(sysCar -> {
                vehiCachService.put(vehiCachService.keyPre() + sysCar.getCarVin(), sysCar);
            });
        });*/
        return Result.success(list);
    }

    /**
     * 导出车辆报文记录列表
     */
    @RequiresPermissions("message:message:export")
    @PostMapping("/export")
    public void export(HttpServletResponse response, SysCarMessage sysCarMessage) {
        List<SysCarMessage> list = sysCarMessageService.selectSysCarMessageList(sysCarMessage);
        ExcelUtil<SysCarMessage> util = new ExcelUtil<SysCarMessage>(SysCarMessage.class);
        util.exportExcel(response, list, "车辆报文记录数据");
    }

    /**
     * 获取车辆报文记录详细信息
     */
    @RequiresPermissions("message:message:query")
    @GetMapping(value = "/{id}")
    public Result<List<SysCarMessage>> getInfo(@PathVariable("id") Long id) {
        return success(sysCarMessageService.selectSysCarMessageById(id));
    }

    /**
     * 新增车辆报文记录
     */
    @RequiresPermissions("message:message:add")
    @PostMapping
    public Result<Integer> add(
            @Validated @RequestBody SysCarMessage sysCarMessage) {

        if (sysCarMessageService.checkIdUnique(sysCarMessage)) {
            return error("新增 车辆报文记录 '" + sysCarMessage + "'失败，车辆报文记录已存在");
        }
        return toAjax(sysCarMessageService.save(sysCarMessage));
    }

    /**
     * 修改车辆报文记录
     */
    @RequiresPermissions("message:message:edit")
    @PutMapping
    public Result<Integer> edit(
            @Validated @RequestBody SysCarMessage sysCarMessage) {
        if (!sysCarMessageService.checkIdUnique(sysCarMessage)) {
            return error("修改 车辆报文记录 '" + sysCarMessage + "'失败，车辆报文记录不存在");
        }


        return toAjax(sysCarMessageService.updateById(sysCarMessage));
    }

    /**
     * 删除车辆报文记录
     */
    @RequiresPermissions("message:message:remove")
    @DeleteMapping("/{ids}")
    public Result<Integer> remove(@PathVariable("ids") Long[] ids) {
        sysCarMessageService.removeBatchByIds(Arrays.asList(ids));
        return success();
    }
}
